import setuptools


setuptools.setup(
    name="ir_digit",
    version="0.0.23",
    author="FKLiu",
    author_email="fkliu001@outlook.com",
    description="digit package",
    long_description="digit package ……",
    long_description_content_type="text",
    url="https://example.com",
    packages=setuptools.find_packages(),
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
